<?php
/**
 * Created by PhpStorm.
 * User: jderosa
 * Date: 25/02/20
 * Time: 14.21
 */
namespace FiloBlu\Rma\Block\Email;
use FiloBlu\Rma\Api\RmaExtensionAttributesRepositoryInterface;
use Magento\Sales\Api\OrderRepositoryInterface;
use Magento\Catalog\Api\ProductRepositoryInterface;
use FiloBlu\Rma\Helper\ChangeSizeAttributeHelper;

class Items extends \Magento\Rma\Block\Email\Items
{
    /**
     * @var RmaExtensionAttributesRepositoryInterface
     */
    private $rmaExtensionAttributesRepository;
    /**
     * @var OrderRepositoryInterface
     */
    private $orderRepository;
    /**
     * @var ProductRepositoryInterface
     */
    private $productRepository;
    /**
     * @var ChangeSizeAttributeHelper
     */
    private $changeSizeAttributeHelper;


    /**
     * Items constructor.
     * @param \Magento\Framework\View\Element\Template\Context $context
     * @param \Magento\Framework\Data\Collection\ModelFactory $modelFactory
     * @param \Magento\Eav\Model\Form\Factory $formFactory
     * @param \Magento\Eav\Model\Config $eavConfig
     * @param \Magento\Rma\Helper\Eav $rmaEav
     * @param RmaExtensionAttributesRepositoryInterface $rmaExtensionAttributesRepository
     * @param OrderRepositoryInterface $orderRepository
     * @param ProductRepositoryInterface $productRepository
     * @param ChangeSizeAttributeHelper $changeSizeAttributeHelper
     * @param array $data
     */
    public function __construct(\Magento\Framework\View\Element\Template\Context $context,
                                \Magento\Framework\Data\Collection\ModelFactory $modelFactory,
                                \Magento\Eav\Model\Form\Factory $formFactory,
                                \Magento\Eav\Model\Config $eavConfig,
                                \Magento\Rma\Helper\Eav $rmaEav,
                                RmaExtensionAttributesRepositoryInterface $rmaExtensionAttributesRepository,
                                OrderRepositoryInterface $orderRepository,
                                ProductRepositoryInterface $productRepository,
                                ChangeSizeAttributeHelper $changeSizeAttributeHelper,
                                array $data = [])
    {
        parent::__construct($context, $modelFactory, $formFactory, $eavConfig, $rmaEav, $data);
        $this->rmaExtensionAttributesRepository = $rmaExtensionAttributesRepository;
        $this->orderRepository = $orderRepository;
        $this->productRepository = $productRepository;
        $this->changeSizeAttributeHelper = $changeSizeAttributeHelper;
    }

    /**
     * @param $myItem
     * @return array
     */
    public function getChangeSizeItems($myItem){

        try{
            $resolution = $myItem->getResolution();
            $newSize = array_fill_keys(['label','value'],'');
            if($this->changeSizeAttributeHelper->getChangeSizeAttributeOptionId() != $resolution){
                return $newSize;
            }

            $changeSizeOrderId  = $this->rmaExtensionAttributesRepository->getChangeSizeOrderId($myItem->getEntityId());
            if($changeSizeOrderId){
                $changeSizeOrder = $this->orderRepository->get($changeSizeOrderId);
                $items = $changeSizeOrder->getItems();
                foreach ($items as $item) {
                    $product = $this->productRepository->get($item->getSku());
                    $newSize ['label'] = $item->getProduct()->getName();
                    $newSize ['value'] = $product->getResource()->getAttribute('size')->getFrontend()->getValue($product);
                }
            }
        }catch (\Exception $e){
            $this->_logger->critical($e->getMessage());
            return $newSize;
        }

        return $newSize;
    }

}