<?php
/**
 * Created by PhpStorm.
 * User: jderosa
 * Date: 10/04/19
 * Time: 11.09
 */

namespace FiloBlu\Rma\Plugin;
use Magento\Framework\App\Config\ScopeConfigInterface;
use Magento\Sales\Model\OrderRepository;
use Magento\Backend\App\Action\Context;

class DisablePersonalizedOrderRma
{

    /**
     * @var OrderRepository
     */
    protected $orderRepository;
    /**
     * @var ScopeConfigInterface
     */
    protected $scopeConfig;
    /**
     * @var RequestInterface
     */
    protected $_request;

    const RMA_CONFIG_PATH = 'filoblu_disablerma_section/rma_group/rma_option_id';

    /**
     * DisablePersonalizedOrderRma constructor.
     * @param Context $context
     * @param OrderRepository $orderRepository
     * @param ScopeConfigInterface $scopeConfig
     */
    public function __construct(Context $context,
                                OrderRepository $orderRepository,
                                ScopeConfigInterface $scopeConfig)
    {
        $this->orderRepository = $orderRepository;
        $this->scopeConfig = $scopeConfig;
        $this->_request = $context->getRequest();
    }


    /**
     * @param \Magento\Rma\Helper\Data $data
     * @param $result
     * @return bool
     */
    public function afterCanCreateRma(\Magento\Rma\Helper\Data $data, $result)
    {

        $config = $this->scopeConfig->getValue(self::RMA_CONFIG_PATH) ?? 0;
        $post = $this->_request->getPostValue();
        if(!empty($post))
        {
            //check in configuration if allow RMA request for personalized orders
            if(!$config )
            {
                if(isset($post['items'][0]['order_item_id']))
                {
                    foreach ($post['items'] as $postItem)
                    {
                        $orderItemId = $postItem['order_item_id'];
                        $orderId = $this->_request->getParam('order_id');
                        try
                        {
                            $order = $this->orderRepository->get($orderId);
                            $allItems = $order->getAllItems();
                            $options = "";
                            //check if request has personalizations
                            foreach ($allItems as $item)
                            {

                                $options = $item->getProductOptions();
                                //check if one of product is personalized and set Param to send to ShowCustomErrorMessageForRma.php
                                if (($item->getItemId() == $orderItemId) && isset($options['options']))
                                {
                                    $result = false;
                                    $this->_request->setParams(array('isPersonalized' => true));
                                }
                                else
                                {
                                    $this->_request->setParams(array('isPersonalized' => false));
                                }
                            }

                        }
                        catch (\Exception $e)
                        {
                            $this->_request->setParams(array('errorMessageFromPlugin' => $e));
                        }
                    }
                }
            }
        }
        else if(!empty($orderId = $this->_request->getParam('order_id')))
        {
            $myOrderitems= $this->orderRepository->get($orderId)->getItems();
            $personalizedItems = [];
            if(!$config) {
                foreach ($myOrderitems as $item) {
                    $options = $item->getProductOptions();
                    if (!empty($options['options'])) {
                        $personalizedItems [] = $item->getItemId();
                    }
                }
            }
            $this->_request->setParams(array('personalizedItems' => $personalizedItems));

        }
        return $result;

    }
    
}