<?php

namespace FiloBlu\Rma\Plugin\Rma\Api\RmaRepositoryInterface;


use Magento\Framework\App\ResourceConnection;
use Magento\Sales\Api\OrderRepositoryInterface;
use Psr\Log\LoggerInterface;
use FiloBlu\Rma\Api\RmaExtensionAttributesRepositoryInterface;
use Magento\Rma\Api\RmaRepositoryInterface;
use Magento\Rma\Model\ResourceModel\Item\CollectionFactory as ItemCollectionFactory;

class AfterGet
{
    /**
     * @var OrderRepositoryInterface
     */
    private $orderRepository;

    /**
     * @var \Magento\Rma\Api\Data\ItemExtensionFactory
     */
    private $extensionInterfaceFactory;
    /**
     * @var ResourceConnection
     */
    private $resourceConnection;
    /**
     * @var LoggerInterface
     */
    protected $logger;

    /**
     * @var RmaExtensionAttributesRepositoryInterface
     */
    protected $rmaExtensionAttributesRepository;

    /**
     * @var ItemCollectionFactory
     */
    protected $itemCollectionFactory;


    /**
     * AfterGet constructor.
     * @param OrderRepositoryInterface $orderRepository
     * @param \Magento\Rma\Api\Data\ItemExtensionFactory $extensionInterfaceFactory
     * @param ResourceConnection $resourceConnection
     * @param LoggerInterface $logger
     * @param RmaExtensionAttributesRepositoryInterface $rmaExtensionAttributesRepository
     * @param ItemCollectionFactory $itemCollectionFactory
     */
    public function __construct(
        OrderRepositoryInterface $orderRepository,
        \Magento\Rma\Api\Data\ItemExtensionFactory $extensionInterfaceFactory,
        ResourceConnection $resourceConnection,
        LoggerInterface $logger,
        RmaExtensionAttributesRepositoryInterface $rmaExtensionAttributesRepository,
        ItemCollectionFactory $itemCollectionFactory)

    {
        $this->orderRepository = $orderRepository;
        $this->extensionInterfaceFactory = $extensionInterfaceFactory;
        $this->resourceConnection = $resourceConnection;
        $this->logger = $logger;
        $this->rmaExtensionAttributesRepository = $rmaExtensionAttributesRepository;
        $this->itemCollectionFactory = $itemCollectionFactory;
    }

    /**
     * @param \Magento\Rma\Api\RmaRepositoryInterface $subject
     * @param \Magento\Rma\Api\Data\RmaInterface $result
     * @return \Magento\Rma\Api\Data\RmaInterface
     */
    public function afterGet(\Magento\Rma\Api\RmaRepositoryInterface $subject, \Magento\Rma\Api\Data\RmaInterface $result)
    {
        if(!$result->getItems()) {
            $orderItems = $this->orderRepository->get($result->getOrderId())->getItems();
            $tmpItems = [];
            foreach ($orderItems as $orderItem){
                $orderItemId = $orderItem->getItemId();

                $tmpItems = $this->itemCollectionFactory->create()->addFieldToSelect('*')->addFieldToFilter('order_item_id',$orderItemId)->getItems() + $tmpItems;
            }
            $rmaItems = $tmpItems;
            $result->setItems($rmaItems);
        }else{
            $rmaItems = $result->getItems();
        }
        foreach ($rmaItems as $rmaItem) {
            $attributes = $rmaItem->getExtensionAttributes();
            if ($attributes === null) {
                /** @var \Magento\Rma\Api\Data\ItemExtensionFactory $attributes */
                $attributes = $this->extensionInterfaceFactory->create();
            }
            if($changeSizeOrderId = $this->rmaExtensionAttributesRepository->getChangeSizeOrderId($rmaItem->getEntityId())){
                try {
                    $attributes->setOrder($this->orderRepository->get($changeSizeOrderId));
                } catch (\Exception $exception) {
                    $this->logger->info($exception->getMessage());
                }

                $rmaItem->setExtensionAttributes($attributes);
            }
        }


        return $result;
    }
}